riksdagen: THis is a description of riksdagen function

Description Usage Arguments Details Value Examples

View source: R/riksdagen.R

Description

riksdagen function uses Riksdagen's API to get data and makes some basic analysis.

Usage

1
riksdagen(voteyear)

Arguments

voteyear

a character with fixed format "YYYY/YY"

Details

The function uses the API to get the voting history grouped by party and makes some basic analysis.

Value

a data frame with percentage of voting data

Examples

1
 riksdagen("2020/21")

chafu696/Lab5 documentation built on Dec. 31, 2020, 9:57 p.m.