runRiksShiny: runRiksShiny

Description Usage Value Examples

View source: R/runRiksShiny.R

Description

runRiksShiny runs an included shiny app allowing the user to see which way each party votes in total by year

Usage

1

Value

runs a Shiny app locally

Examples

1
 ## Not run: runRiksShiny()

chafu696/Lab5 documentation built on Dec. 31, 2020, 9:57 p.m.