Description Usage Arguments Details Value Examples
riksdagen function uses Riksdagen's API to get data and makes some basic analysis.
1 | riksdagen(voteyear)
|
voteyear |
a character with fixed format "YYYY/YY" |
The function uses the API to get the voting history grouped by party and makes some basic analysis.
a data frame with percentage of voting data
1 | riksdagen("2020/21")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.