Description Usage Value Examples
runRiksShiny runs an included shiny app allowing the user to see which way each party votes in total by year
1 |
runs a Shiny app locally
1 | ## Not run: runRiksShiny()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.